==> sfs-2.00.tar.gz: sfs-2.00/programs/pluto/certs.h <==
/* Certificate support for IKE authentication
 * Copyright (C) 2002 Andreas Steffen, Zuercher Hochschule Winterthur
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  See <http://www.fsf.org/copyleft/gpl.txt>.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * RCSID $Id: certs.h,v 1.2 2003/07/21 02:17:05 ken Exp $
 */

/* path definitions for private keys, end certs,
 * cacerts, attribute certs and crls
 */
#define PRIVATE_KEY_PATH  "/etc/ipsec.d/private"
#define HOST_CERT_PATH    "/etc/ipsec.d/certs"
#define CA_CERT_PATH	  "/etc/ipsec.d/cacerts"
#define A_CERT_PATH	  "/etc/ipsec.d/acerts"
#define CRL_PATH	  "/etc/ipsec.d/crls"

/* advance warning of imminent expiry of
 * cacerts, public keys, and crls
 */
#define CA_CERT_WARNING_INTERVAL	30 /* days */
#define PUBKEY_WARNING_INTERVAL		 7 /* days */
#define CRL_WARNING_INTERVAL		 7 /* days */

/* access structure for RSA private keys */

typedef struct rsa_privkey rsa_privkey_t;

struct rsa_privkey {
    chunk_t keyobject;
    chunk_t field[8];
};

/* used for initialization */
extern const rsa_privkey_t empty_rsa_privkey;

/* certificate access structure
 * currently X.509 and OpenPGP certificates are supported
 */
typedef struct {
    u_char type;
    union {
	x509cert_t *x509;
	pgpcert_t  *pgp;
    } u;
} cert_t;

/*  do not send certificate requests
 *  flag set in plutomain.c and used in ipsec_doi.c
 */
extern bool no_cr_send;

extern rsa_privkey_t* load_rsa_private_key(const char* filename
    ,const char* passphrase);
extern chunk_t get_mycert(cert_t cert);
extern bool load_coded_file(const char *filename, const char *passphrase
    , const char *type, chunk_t *blob, bool *pgp);
extern bool load_cert(const char *filename, const char *label
    , cert_t *cert);
extern bool load_host_cert(const char *filename, cert_t *cert);
extern void share_cert(cert_t cert);
extern void release_cert(cert_t cert);
extern void list_certs(bool utc);

==> sfs-2.02.0.tar.gz: sfs-2.02.0/programs/pluto/certs.h <==
/* Certificate support for IKE authentication
 * Copyright (C) 2002-2003 Andreas Steffen, Zuercher Hochschule Winterthur
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  See <http://www.fsf.org/copyleft/gpl.txt>.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * RCSID $Id: certs.h,v 1.1 2003/09/12 19:24:42 ken Exp $
 */

/* path definitions for private keys, end certs,
 * cacerts, attribute certs and crls
 */
#define PRIVATE_KEY_PATH  "/etc/ipsec.d/private"
#define HOST_CERT_PATH    "/etc/ipsec.d/certs"
#define CA_CERT_PATH	  "/etc/ipsec.d/cacerts"
#define A_CERT_PATH	  "/etc/ipsec.d/acerts"
#define CRL_PATH	  "/etc/ipsec.d/crls"

/* advance warning of imminent expiry of
 * cacerts, public keys, and crls
 */
#define CA_CERT_WARNING_INTERVAL	30 /* days */
#define PUBKEY_WARNING_INTERVAL		 7 /* days */
#define CRL_WARNING_INTERVAL		 7 /* days */

/* access structure for RSA private keys */

typedef struct rsa_privkey rsa_privkey_t;

struct rsa_privkey {
    chunk_t keyobject;
    chunk_t field[8];
};

/* used for initialization */
extern const rsa_privkey_t empty_rsa_privkey;

/* certificate access structure
 * currently X.509 and OpenPGP certificates are supported
 */
typedef struct {
    u_char type;
    union {
	x509cert_t *x509;
	pgpcert_t  *pgp;
    } u;
} cert_t;

/*  do not send certificate requests
 *  flag set in plutomain.c and used in ipsec_doi.c
 */
extern bool no_cr_send;

extern rsa_privkey_t* load_rsa_private_key(const char* filename
    , prompt_pass_t *pass);
extern chunk_t get_mycert(cert_t cert);
extern bool load_coded_file(const char *filename, prompt_pass_t *pass
    , const char *type, chunk_t *blob, bool *pgp);
extern bool load_cert(const char *filename, const char *label
    , cert_t *cert);
extern bool load_host_cert(const char *filename, cert_t *cert);
extern void share_cert(cert_t cert);
extern void release_cert(cert_t cert);
extern void list_certs(bool utc);
